@@ -11,7 +11,7 @@
 //
 #include "kmfpfcompiler.h"
 
-// QT includes
+// TQt includes
 #include <tqptrlist.h>
 #include <tqstringlist.h>
 #include <tqmultilineedit.h>
@@ -45,7 +45,7 @@ KMFPFCompiler::KMFPFCompiler( TQObject* parent, const char* name ) : KMFPlugin(
 	
 	if ( genericDoc() ) {
 		new TDEAction( i18n( "Export as &PF (OpenBSD) Script" ),  "fileexport",
-									0, this, TQT_SLOT( slotExportPF() ), actionCollection(), "compile_pf" );
+									0, this, TQ_SLOT( slotExportPF() ), actionCollection(), "compile_pf" );
 
 		setXMLFile( "kmfpfcompiler.rc" );
 		kdDebug() << "KMFPFCompiler: Finished initialisation." << endl;
