@@ -17,11 +17,11 @@
 #define KMFAPP_H
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 /**
   *@author Christian Hubinger
@@ -31,7 +31,7 @@ class TQLabel;
 namespace KMF {
 
 
-class KDE_EXPORT KMFApp : public KApplication  {
+class KDE_EXPORT KMFApp : public TDEApplication  {
 public: 
 	KMFApp();
 	~KMFApp();
