@@ -16,12 +16,12 @@
 @author Christian Hubinger
 */
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 #include <tqobject.h>
 
 // KDE Includes
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 
 namespace KMF {
