@@ -21,7 +21,7 @@
 
 #include "kmfnetzone.h"
 
-// QT includes
+// TQt includes
 #include <tqdom.h>
 #include <tqvaluelist.h>
 #include <tqobject.h>
@@ -463,10 +463,10 @@ KMFProtocolUsage* KMFNetZone::addProtocolUsage( const TQUuid& protocolUuid, cons
 	}
 	new_protocol->setProtocol( prot );
 	m_protocols.append( new_protocol );
-	disconnect( new_protocol, TQT_SIGNAL( destroyed( TQObject* ) ),
-		this, TQT_SLOT( slotOnProtocolUsageDeleted( TQObject* ) ) );
-	connect( new_protocol, TQT_SIGNAL( destroyed( TQObject* ) ),
-		this, TQT_SLOT( slotOnProtocolUsageDeleted( TQObject* ) ) );
+	disconnect( new_protocol, TQ_SIGNAL( destroyed( TQObject* ) ),
+		this, TQ_SLOT( slotOnProtocolUsageDeleted( TQObject* ) ) );
+	connect( new_protocol, TQ_SIGNAL( destroyed( TQObject* ) ),
+		this, TQ_SLOT( slotOnProtocolUsageDeleted( TQObject* ) ) );
 	changed();
 	return new_protocol;
 }
