@@ -14,7 +14,7 @@
 
 #include "netfilterobject.h"
 
-// QT includes
+// TQt includes
 #include <tqstringlist.h>
 #include <tqstring.h>
 #include <tqguardedptr.h>
@@ -36,7 +36,7 @@ class KMFProtocol;
 
 class KDE_EXPORT KMFProtocolCategory : public NetfilterObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	static KMFProtocolCategory* createCategory( const TQString& name );
