@@ -11,7 +11,7 @@
 //
 #include "kmfprotocolusage.h"
 
-// QT includes
+// TQt includes
 #include <tqfile.h>
 #include <tqdir.h>
 #include <tqdom.h>
@@ -87,10 +87,10 @@ void KMFProtocolUsage::setProtocol( KMFProtocol* p ) {
 	// kdDebug() << "KMFProtocolUsage::setProtocol( KMFProtocol* " << p->name() << " )" << endl;
 	m_protocol = p;
 	
-	disconnect( m_protocol, TQT_SIGNAL( destroyed( TQObject* ) ),
-		this, TQT_SLOT( slotOnProtocolDeleted( TQObject* ) ) );
-	connect( m_protocol, TQT_SIGNAL( destroyed( TQObject* ) ),
-		this, TQT_SLOT( slotOnProtocolDeleted( TQObject* ) ) );
+	disconnect( m_protocol, TQ_SIGNAL( destroyed( TQObject* ) ),
+		this, TQ_SLOT( slotOnProtocolDeleted( TQObject* ) ) );
+	connect( m_protocol, TQ_SIGNAL( destroyed( TQObject* ) ),
+		this, TQ_SLOT( slotOnProtocolDeleted( TQObject* ) ) );
 }
 
 void KMFProtocolUsage::slotOnProtocolDeleted( TQObject* ) {
