@@ -14,7 +14,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2008
 
 #include "netfilterobject.h"
 
-// QT includes
+// TQt includes
 
 #include <tqptrlist.h>
 #include <tqstring.h>
@@ -45,7 +45,7 @@ class KMFCompilerInterface;
 */
 
 class KDE_EXPORT KMFTarget : public NetfilterObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFTarget( NetfilterObject *parent, const char* name, const TQString& targetName, KMFNetwork* net );
