@@ -11,7 +11,7 @@
 //
 #include "kprocesswrapper.h"
 
-// QT Includes
+// TQt Includes
 #include <tqwidget.h>
 #include <tquuid.h>
 #include <tqfile.h>
@@ -36,7 +36,7 @@ namespace KMF {
 TDEProcessWrapper* TDEProcessWrapper::m_instance = 0;
 TDEProcessWrapper* TDEProcessWrapper::instance() {
 	if ( ! m_instance ) {
-		m_instance = new TDEProcessWrapper( TQT_TQOBJECT(TDEApplication::kApplication()->mainWidget()) , "TDEProcessWrapper" );
+		m_instance = new TDEProcessWrapper( TDEApplication::kApplication()->mainWidget() , "TDEProcessWrapper" );
 	}
 	return m_instance;
 }
@@ -51,9 +51,9 @@ TDEProcessWrapper::TDEProcessWrapper( TQObject* parent,  const char* name ) : TQ
 	m_status = -1;
 	m_exitedNormal = false;
 	
-	connect( m_childproc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQT_SLOT( slotReceivedOutput( TDEProcess*, char*, int ) ) );
-	connect( m_childproc, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), this, TQT_SLOT( slotReceivedError( TDEProcess*, char*, int ) ) );
-	connect( m_childproc, TQT_SIGNAL( processExited( TDEProcess* ) ), this, TQT_SLOT( slotProcessExited( TDEProcess* ) ) ) ;
+	connect( m_childproc, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQ_SLOT( slotReceivedOutput( TDEProcess*, char*, int ) ) );
+	connect( m_childproc, TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), this, TQ_SLOT( slotReceivedError( TDEProcess*, char*, int ) ) );
+	connect( m_childproc, TQ_SIGNAL( processExited( TDEProcess* ) ), this, TQ_SLOT( slotProcessExited( TDEProcess* ) ) ) ;
 }
 
 TDEProcessWrapper::~TDEProcessWrapper()
