@@ -13,7 +13,7 @@
 #define KMFKPROCESSWRAPPER_H
 
 
-// QT Includes
+// TQt Includes
 #include <tqobject.h>
 #include <tqstring.h>
 
@@ -30,7 +30,7 @@ class KMFTarget;
 	@author Christian Hubinger <chubinger@irrsinnig.org>
 */
 class TDEProcessWrapper : public TQObject {
-Q_OBJECT
+TQ_OBJECT
   
 
 //############# Beginn static stuff ##############	
