@@ -14,7 +14,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 #include "kmfgenericinterface_part.h"
 
 
-// QT includes
+// TQt includes
 #include <tqlabel.h>
 
 // KDE includes
@@ -49,39 +49,39 @@ KMFGenericInterfacePart::KMFGenericInterfacePart( TQWidget *parentWidget, const
 	}
 
 	m_genericinterface->loadDoc( m_app->network() );
-	connect( m_genericinterface, TQT_SIGNAL( sigTargetChanged() ),
-		this, TQT_SLOT( slotTargetChanged() ) );
+	connect( m_genericinterface, TQ_SIGNAL( sigTargetChanged() ),
+		this, TQ_SLOT( slotTargetChanged() ) );
 	
-	connect( m_app, TQT_SIGNAL( sigUpdateView() ),
-		m_genericinterface, TQT_SIGNAL( sigUpdateView() ) );
+	connect( m_app, TQ_SIGNAL( sigUpdateView() ),
+		m_genericinterface, TQ_SIGNAL( sigUpdateView() ) );
 
-	connect( m_app, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-		m_genericinterface, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ) );
+	connect( m_app, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+		m_genericinterface, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ) );
 
-	connect( m_app, TQT_SIGNAL( sigEnableActions( bool ) ),
-		this, TQT_SLOT( slotEnableActions( bool ) ) );
+	connect( m_app, TQ_SIGNAL( sigEnableActions( bool ) ),
+		this, TQ_SLOT( slotEnableActions( bool ) ) );
 
 	
 	m_actionGoMyNetwork = new TDEAction( i18n( "&My Network" ), TQIconSet( BarIcon( "network", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoMyNetwork() ), actionCollection(), "my_network" );
+	                                 0 , this, TQ_SLOT( slotGoMyNetwork() ), actionCollection(), "my_network" );
 
 	m_actionGoAccessControl = new TDEAction( i18n( "&Access Control" ), TQIconSet( BarIcon( "services", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoAccessControl() ), actionCollection(), "access_control" );
+	                                 0 , this, TQ_SLOT( slotGoAccessControl() ), actionCollection(), "access_control" );
 
 
 	m_actionGoSpecialHosts = new TDEAction( i18n( "&Special Hosts Control" ), TQIconSet( BarIcon( "network_local", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoSpecialHosts() ), actionCollection(), "special_hosts" );
+	                                 0 , this, TQ_SLOT( slotGoSpecialHosts() ), actionCollection(), "special_hosts" );
 
 
 	m_actionGoICMPOptions = new TDEAction( i18n( "&ICMP Options" ), TQIconSet( BarIcon( "pipe", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoICMPOptions() ), actionCollection(), "icmp_options" );
+	                                 0 , this, TQ_SLOT( slotGoICMPOptions() ), actionCollection(), "icmp_options" );
 
 	
 	m_actionGoNATConfiguration = new TDEAction( i18n( "&NAT Configuration" ), TQIconSet( BarIcon( "document-save-as", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoNATConfiguration() ), actionCollection(), "nat_configuration" );
+	                                 0 , this, TQ_SLOT( slotGoNATConfiguration() ), actionCollection(), "nat_configuration" );
 	
 	m_actionGoLogging = new TDEAction( i18n( "&Logging" ), TQIconSet( BarIcon( "text-x-log", KMFGenericInterfacePartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotGoLogging() ), actionCollection(), "logging_options" );
+	                                 0 , this, TQ_SLOT( slotGoLogging() ), actionCollection(), "logging_options" );
 
 
 	setWidget( m_genericinterface );
