@@ -14,7 +14,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 #include "kmfinstallerplugin.h"
 
 
-// QT includes
+// TQt includes
 #include <tqfile.h>
 #include <tqtextstream.h>
 #include <tqmultilineedit.h>
@@ -74,28 +74,28 @@ KMFInstallerPlugin::KMFInstallerPlugin( TQObject *parent, const char *name )
 // 	m_installerPlugin = 0;
 	m_execWidget = 0;
 	m_actionStopFw = new TDEAction( i18n( "&Reset IPTables" ), "decrypted",
-	                              0, this, TQT_SLOT( slotStopFirewall() ), actionCollection(), "reset_iptables" );
+	                              0, this, TQ_SLOT( slotStopFirewall() ), actionCollection(), "reset_iptables" );
 
 	m_actionRunFw = new TDEAction( i18n( "Run Fir&ewall" ), "encrypted",
-	                             0, this, TQT_SLOT( slotStartFirewall() ), actionCollection(), "run_firewall" );
+	                             0, this, TQ_SLOT( slotStartFirewall() ), actionCollection(), "run_firewall" );
 
 	m_actionPreviewScript = new TDEAction( i18n( "&Preview Script" ), "mime_txt",
-	                                     0 , this, TQT_SLOT( slotShowScript() ), actionCollection(), "preview_script" );
+	                                     0 , this, TQ_SLOT( slotShowScript() ), actionCollection(), "preview_script" );
 
 	m_generateInstallPackage  = new TDEAction( i18n( "&Generate Linux Installation Package" ), "fileexport",
-			0 , this, TQT_SLOT( slotGenerateInstallerPackage() ), actionCollection(), "generate_install_package" );
+			0 , this, TQ_SLOT( slotGenerateInstallerPackage() ), actionCollection(), "generate_install_package" );
 	
 	m_actionShowConfig = new TDEAction( i18n( "Show &All Tables" ), "messagebox_info",
-	                                  0 , this, TQT_SLOT( slotShowConfig() ), actionCollection(), "show_ipt_config" );
+	                                  0 , this, TQ_SLOT( slotShowConfig() ), actionCollection(), "show_ipt_config" );
 
 	m_actionShowFilter = new TDEAction( i18n( "Show &Filter Table" ), "messagebox_info",
-	                                  0 , this, TQT_SLOT( slotShowFilter() ), actionCollection(), "show_filter" );
+	                                  0 , this, TQ_SLOT( slotShowFilter() ), actionCollection(), "show_filter" );
 
 	m_actionShowNat = new TDEAction( i18n( "Show &Nat Table" ), "messagebox_info",
-	                               0 , this, TQT_SLOT( slotShowNat() ), actionCollection(), "show_nat" );
+	                               0 , this, TQ_SLOT( slotShowNat() ), actionCollection(), "show_nat" );
 
 	m_actionShowMangle = new TDEAction( i18n( "Show &Mangle Table" ), "messagebox_info",
-	                                  0 , this, TQT_SLOT( slotShowMangle() ), actionCollection(), "show_mangle" );
+	                                  0 , this, TQ_SLOT( slotShowMangle() ), actionCollection(), "show_mangle" );
 
 	m_actionMenu = new TDEActionMenu( i18n( "Show IPTables Configuration" ), "messagebox_info", this , "show_menu" );
 
@@ -108,15 +108,15 @@ KMFInstallerPlugin::KMFInstallerPlugin( TQObject *parent, const char *name )
 	actionCollection() ->insert( m_actionMenu );
 
 	m_actionInstallFW = new TDEAction( i18n( "&Install Firewall" ), "go-down",
-	                                 0 , this, TQT_SLOT( slotInstallFW() ), actionCollection(), "install_firewall" );
+	                                 0 , this, TQ_SLOT( slotInstallFW() ), actionCollection(), "install_firewall" );
 
 	m_actionUninstallFW = new TDEAction( i18n( "&Uninstall Firewall" ), "go-up",
-	                                   0 , this, TQT_SLOT( slotUninstallFW() ), actionCollection(), "uninstall_firewall" );
+	                                   0 , this, TQ_SLOT( slotUninstallFW() ), actionCollection(), "uninstall_firewall" );
 	setXMLFile( "kmfinstallerpluginui.rc" );
 
 	slotEnableActions( false );
-	connect( app,TQT_SIGNAL( sigEnableActions( bool ) ),
-         this, TQT_SLOT( slotEnableActions(bool ) ) );
+	connect( app,TQ_SIGNAL( sigEnableActions( bool ) ),
+         this, TQ_SLOT( slotEnableActions(bool ) ) );
 
 	kdDebug() << "KMFInstallerPlugin: Finished Initialisationn " << endl;
 }
