@@ -12,7 +12,7 @@ email                : chubinger@irrsinnig.org
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/ 
-// QT includes
+// TQt includes
 #include <tqlabel.h>
 #include <tqpushbutton.h>
 #include <tqlayout.h>
@@ -114,8 +114,8 @@ KMFProcOut* KMFIPTInstaller::execWidget(){
 	}
 	kdDebug() << "Need to create new execWidget." << endl;
 	m_execWidget = new KMFProcOut( 0, "KMFProcOut" );
-	connect( m_execWidget, TQT_SIGNAL( sigJobFinished( bool, const TQString& ) ),
-		this, TQT_SLOT( slotJobFinished( bool, const TQString& ) ) );
+	connect( m_execWidget, TQ_SIGNAL( sigJobFinished( bool, const TQString& ) ),
+		this, TQ_SLOT( slotJobFinished( bool, const TQString& ) ) );
 	setOutputWidget( m_execWidget );
 	return m_execWidget;
 }
