@@ -15,7 +15,7 @@ email                : chubinger@irrsinnig.org
 
 #include "kmfpfinstaller.h"
 
-// QT includes
+// TQt includes
 #include <tqlabel.h>
 #include <tqpushbutton.h>
 #include <tqlayout.h>
@@ -128,8 +128,8 @@ KMFProcOut* KMFPFInstaller::execWidget(){
 	}
 	kdDebug() << "Need to create new execWidget." << endl;
 	m_execWidget = new KMFProcOut( 0, "KMFProcOut" );
-	connect( m_execWidget, TQT_SIGNAL( sigJobFinished( bool, const TQString& ) ),
-		this, TQT_SLOT( slotJobFinished( bool, const TQString& ) ) );
+	connect( m_execWidget, TQ_SIGNAL( sigJobFinished( bool, const TQString& ) ),
+		this, TQ_SLOT( slotJobFinished( bool, const TQString& ) ) );
 	setOutputWidget( m_execWidget );
 	return m_execWidget;
 }
