@@ -47,7 +47,7 @@ class KMFErrorHandler;
 class KMFCompilerInterface;
 
 class KMFPFInstaller :  public KMFPlugin, public KMFInstallerInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -104,13 +104,13 @@ private:
 
 
 class KMFPFInstallerFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFPFInstallerFactory( TQObject *parent = 0, const char *name = 0 );
 	virtual ~KMFPFInstallerFactory() {};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 };
 }
