@@ -13,7 +13,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 #include "kmfipteditorpart.h"
 
 
-// QT includes
+// TQt includes
 #include <tqfile.h>
 #include <tqtextstream.h>
 #include <tqmultilineedit.h>
@@ -57,7 +57,7 @@ KMFIPTEditorPart::KMFIPTEditorPart( TQWidget *parentWidget, const char *widgetNa
 	// this should be your custom internal widget
 	m_ruleedit = new KMFRuleEdit( parentWidget, widgetName );
 	m_ruleedit->setKMFMainWindow( app );
-	m_ruleedit->setFocusPolicy( TQ_ClickFocus );
+	m_ruleedit->setFocusPolicy( TQWidget::ClickFocus );
 	
 	m_editdoc = new KMFIPTDocOptions( parentWidget , "m_editdoc" );
 	m_editdoc->hide();
@@ -65,44 +65,44 @@ KMFIPTEditorPart::KMFIPTEditorPart( TQWidget *parentWidget, const char *widgetNa
 	m_ruleedit->loadDoc( app->network() );
 	m_editdoc->loadDoc( app->network()->currentDocAsIPTDoc() );
 	
-	connect( app, TQT_SIGNAL( sigUpdateView() ),
-		m_ruleedit, TQT_SLOT( slotUpdateView() ) );
+	connect( app, TQ_SIGNAL( sigUpdateView() ),
+		m_ruleedit, TQ_SLOT( slotUpdateView() ) );
 
-	connect( app, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-		m_ruleedit, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ) );
+	connect( app, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+		m_ruleedit, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ) );
 
-	connect( app, TQT_SIGNAL( sigEnableActions( bool ) ),
-		this, TQT_SLOT( slotEnableActions( bool ) ) );
+	connect( app, TQ_SIGNAL( sigEnableActions( bool ) ),
+		this, TQ_SLOT( slotEnableActions( bool ) ) );
 
-	connect ( m_editdoc, TQT_SIGNAL( sigConfigChanged() ),
-	          m_ruleedit, TQT_SLOT( slotUpdateView() ) );
+	connect ( m_editdoc, TQ_SIGNAL( sigConfigChanged() ),
+	          m_ruleedit, TQ_SLOT( slotUpdateView() ) );
 
 	// notify the part that this is our internal widget
 	setWidget( m_ruleedit );
 	
 	m_actionEditChain = new TDEAction( i18n( "&Edit Chain" ), TQIconSet( BarIcon( "configure_toolbars", KMFIPTEditorPartFactory::instance() ) ),
-	                                 0 , this, TQT_SLOT( slotEditChain() ), actionCollection(), "edit_chain" );
+	                                 0 , this, TQ_SLOT( slotEditChain() ), actionCollection(), "edit_chain" );
 
 	m_actionNewChain = new TDEAction( i18n( "Add New Chain..." ), TQIconSet( BarIcon( "view_tree", KMFIPTEditorPartFactory::instance() ) ),
-	                                0 , this, TQT_SLOT( slotNewChain() ), actionCollection(), "new_chain" );
+	                                0 , this, TQ_SLOT( slotNewChain() ), actionCollection(), "new_chain" );
 
 	m_actionDelChain = new TDEAction( i18n( "Delete Chain" ), TQIconSet( BarIcon( "edit-delete", KMFIPTEditorPartFactory::instance() ) ),
-	                                0 , this, TQT_SLOT( slotDelChain() ), actionCollection(), "del_chain" );
+	                                0 , this, TQ_SLOT( slotDelChain() ), actionCollection(), "del_chain" );
 
 	
 	m_actionNewRule = new TDEAction( i18n( "Add New Rule..." ), TQIconSet( TDEGlobal:: iconLoader()->loadIcon( "rule", TDEIcon::Toolbar ) ) ,
-								   TDEStdAccel::shortcut(TDEStdAccel::New) , this, TQT_SLOT( slotNewRule() ), actionCollection(), "new_rule" );
+								   TDEStdAccel::shortcut(TDEStdAccel::New) , this, TQ_SLOT( slotNewRule() ), actionCollection(), "new_rule" );
 	
 //	m_actionNewRule->setIconSet( TQIconSet(  loader->loadIcon( "rule-22", TDEIcon::User ) ) );							   
 								   
 	m_actionDelRule = new TDEAction( i18n( "Delete Rule" ), TQIconSet( BarIcon( "edit-delete", KMFIPTEditorPartFactory::instance() ) ),
-								   TDEStdAccel::shortcut(TDEStdAccel::DeleteWordBack), this, TQT_SLOT( slotDelRule() ), actionCollection(), "del_rule" );
+								   TDEStdAccel::shortcut(TDEStdAccel::DeleteWordBack), this, TQ_SLOT( slotDelRule() ), actionCollection(), "del_rule" );
 	
-	m_actionEditDocOptions = new TDEAction( i18n( "&Configure Firewall Options..." ), "configure", 0 , this, TQT_SLOT( slotEditDocOptions() ),
+	m_actionEditDocOptions = new TDEAction( i18n( "&Configure Firewall Options..." ), "configure", 0 , this, TQ_SLOT( slotEditDocOptions() ),
 	                                    actionCollection(), "edit_doc_options" );
 
 	
-	m_actionEditNetwork = new TDEAction( i18n( "&Configure the Network" ), TQIconSet( BarIcon( "configure_toolbars", KMFIPTEditorPartFactory::instance() ) ), 0 , this, TQT_SLOT( slotEditNetwork() ),
+	m_actionEditNetwork = new TDEAction( i18n( "&Configure the Network" ), TQIconSet( BarIcon( "configure_toolbars", KMFIPTEditorPartFactory::instance() ) ), 0 , this, TQ_SLOT( slotEditNetwork() ),
 	                                    actionCollection(), "edit_network" );
 
 	
