@@ -32,7 +32,7 @@ class KMFErrorHandler;
 class KMFCheckInput;
 
 class KMFNewChainDlg : public KMyFirewallChainEditorNewChain {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFNewChainDlg( TQWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
