@@ -30,7 +30,7 @@ email                : chubinger@irrsinnig.org
 #include <tdeparts/plugin.h>
 #include <tdeparts/factory.h>
 
-//QT includes
+//TQt includes
 #include <tqtooltip.h>
 #include <tqwhatsthis.h>
 #include <tqheader.h>
@@ -92,22 +92,22 @@ KMFRuleEdit::KMFRuleEdit( TQWidget* parent, const char* name, WFlags fl )
 	m_err = new KMFError();
 	m_err_handler = new KMFErrorHandler( "KMFRuleEdit" );
 	kb_optSelect->clear();
-	connect( kb_optSelect, TQT_SIGNAL( activated( int ) ) , this, TQT_SLOT( slotNewOptionType( int ) ) );
+	connect( kb_optSelect, TQ_SIGNAL( activated( int ) ) , this, TQ_SLOT( slotNewOptionType( int ) ) );
 
 	m_lv_table_filter = new KMFListView( m_widgetStack, "m_lv_table_filter" );
 	m_lv_table_filter->show();
 
-	connect( m_lv_table_filter, TQT_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
-	         this, TQT_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_lv_table_filter, TQ_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
+	         this, TQ_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
 
-	connect( m_lv_table_filter, TQT_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
-	         this, TQT_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
+	connect( m_lv_table_filter, TQ_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
+	         this, TQ_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
 
-	connect( m_lv_table_filter, TQT_SIGNAL( clicked( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
+	connect( m_lv_table_filter, TQ_SIGNAL( clicked( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
 	
-// 	connect( this, TQT_SIGNAL( sigUpdateView() ),
-// 	         m_lv_table_filter, TQT_SLOT( slotUpdateView() ) );
+// 	connect( this, TQ_SIGNAL( sigUpdateView() ),
+// 	         m_lv_table_filter, TQ_SLOT( slotUpdateView() ) );
 	
 	m_widgetStack->addWidget( m_lv_table_filter );
 
@@ -115,28 +115,28 @@ KMFRuleEdit::KMFRuleEdit( TQWidget* parent, const char* name, WFlags fl )
 	m_lv_table_nat = new KMFListView( m_widgetStack, "m_lv_table_nat" );
 	m_lv_table_nat->show();
 
-	connect( m_lv_table_nat, TQT_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
-	         this, TQT_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_lv_table_nat, TQ_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
+	         this, TQ_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
 
-	connect( m_lv_table_nat, TQT_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
-	         this, TQT_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
+	connect( m_lv_table_nat, TQ_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
+	         this, TQ_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
 
-	connect( m_lv_table_nat, TQT_SIGNAL( clicked( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
+	connect( m_lv_table_nat, TQ_SIGNAL( clicked( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
 
 	m_widgetStack->addWidget( m_lv_table_nat );
 
 	m_lv_table_mangle = new KMFListView( m_widgetStack, "m_lv_table_mangle" );
 	m_lv_table_mangle->show();
 
-	connect( m_lv_table_mangle, TQT_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
-	         this, TQT_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
+	connect( m_lv_table_mangle, TQ_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
+	         this, TQ_SLOT( slotRuleRBM( TQListViewItem*, const TQPoint&, int ) ) );
 
-	connect( m_lv_table_mangle, TQT_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
-	         this, TQT_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
+	connect( m_lv_table_mangle, TQ_SIGNAL( itemRenamed ( TQListViewItem*, int, const TQString& ) ),
+	         this, TQ_SLOT( slotRenameRule( TQListViewItem*, int, const TQString& ) ) );
 
-	connect( m_lv_table_mangle, TQT_SIGNAL( clicked( TQListViewItem* ) ),
-	         this, TQT_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
+	connect( m_lv_table_mangle, TQ_SIGNAL( clicked( TQListViewItem* ) ),
+	         this, TQ_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
 	
 	
 	
@@ -146,37 +146,37 @@ KMFRuleEdit::KMFRuleEdit( TQWidget* parent, const char* name, WFlags fl )
 
 	m_editchain = new KMFChainEdit( this, "chianditor", 0 );
 	kdDebug() << "CONNECTING CHAINEDITOR" << endl;
-	connect( m_editchain, TQT_SIGNAL( sigHideMe() ),
-	         this, TQT_SLOT( slotShowOverview() ) );
+	connect( m_editchain, TQ_SIGNAL( sigHideMe() ),
+	         this, TQ_SLOT( slotShowOverview() ) );
 	m_widgetStack->addWidget( m_editchain );
 
 
 	m_object_info = new KMFObjectInfo( this, "rule info" );
-	connect( m_object_info, TQT_SIGNAL( sigHideMe() ),
-	         this, TQT_SLOT( slotShowOverview() ) );
+	connect( m_object_info, TQ_SIGNAL( sigHideMe() ),
+	         this, TQ_SLOT( slotShowOverview() ) );
 
 	m_widgetStack->addWidget( m_object_info );
 
 	m_new_chain = new KMFNewChainDlg();
-	connect( m_new_chain, TQT_SIGNAL( sigUpdateView() ),
-	         this, TQT_SIGNAL( sigUpdateView() ) );
+	connect( m_new_chain, TQ_SIGNAL( sigUpdateView() ),
+	         this, TQ_SIGNAL( sigUpdateView() ) );
 
 	m_myNetworkWidget = new KMFMyNetworkWidget( this, "KMFMyNetworkWidget" );
-	connect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_myNetworkWidget, TQT_SLOT( slotUpdateView() ) );
-	connect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_myNetworkWidget, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+	connect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_myNetworkWidget, TQ_SLOT( slotUpdateView() ) );
+	connect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_myNetworkWidget, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 	
-	connect( m_myNetworkWidget, TQT_SIGNAL( sigActiveTargetChanged() ), this, TQT_SLOT( slotUpdateView() ) );
+	connect( m_myNetworkWidget, TQ_SIGNAL( sigActiveTargetChanged() ), this, TQ_SLOT( slotUpdateView() ) );
 	m_myNetworkWidget->hide(); //close( false );
 
 	m_check_input = new KMFCheckInput();
 	m_contextMenu = new TDEPopupMenu( this );
 	
-	connect( cb_log_rule, TQT_SIGNAL( clicked() ),
-	         this, TQT_SLOT( slotLogRuleChanged() ) );
-	connect( cb_disable_rule, TQT_SIGNAL( clicked() ),
-	         this, TQT_SLOT( slotEnableRuleChanged() ) );
+	connect( cb_log_rule, TQ_SIGNAL( clicked() ),
+	         this, TQ_SLOT( slotLogRuleChanged() ) );
+	connect( cb_disable_rule, TQ_SIGNAL( clicked() ),
+	         this, TQ_SLOT( slotEnableRuleChanged() ) );
 	rb_filter->setChecked( true );
 	
 	loadPlugins();
@@ -312,13 +312,13 @@ void KMFRuleEdit::slotLoadDocument( KMFNetwork* network ) {
 void KMFRuleEdit::loadPlugins() {
 	kdDebug() << "KMFRuleEdit::loadPlugins()" << endl;
 	
-	TQPtrListIterator<KMFRuleOptionEditInterface> it( *KMFPluginFactory::KMFRuleOptionEditors( TQT_TQOBJECT(this) ) );
+	TQPtrListIterator<KMFRuleOptionEditInterface> it( *KMFPluginFactory::KMFRuleOptionEditors( this ) );
 	while( it.current() ) {
 		registerRuleOptionPlugin( it.current() );
 		++it;
 	}
 	
-	TQPtrListIterator<KMFRuleTargetOptionEditInterface> it2(  *KMFPluginFactory::KMFRuleTargetOptionEditors( TQT_TQOBJECT(this) ) );
+	TQPtrListIterator<KMFRuleTargetOptionEditInterface> it2(  *KMFPluginFactory::KMFRuleTargetOptionEditors( this ) );
 	while( it2.current() ) {
 		registerRuleTargetOptionPlugin( it2.current() );
 		++it2;
@@ -406,91 +406,91 @@ void KMFRuleEdit::setCurrTableView( KMFListView* lv ) {
 		setEnabled( true );
 		kdDebug() << "Enabling Filter View" << endl;
 		m_lv_table_filter->setEnabled( true );
-		connect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView() ) );
+		connect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView() ) );
 		
-		connect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		connect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Nat View" << endl;
 		m_lv_table_nat->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_nat, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_nat, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_nat, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_nat, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Mangle View" << endl;
 		m_lv_table_mangle->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 	} else if  ( lv == m_lv_table_nat ) {
 		setEnabled( true );
 		kdDebug() << "Disabling Filter View" << endl;
 		m_lv_table_filter->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Enabling Nat View" << endl;
 		m_lv_table_nat->setEnabled( true );
-		connect( this, TQT_SIGNAL( sigUpdateView() ),
-			m_lv_table_nat, TQT_SLOT( slotUpdateView() ) );
-		connect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-			m_lv_table_nat, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		connect( this, TQ_SIGNAL( sigUpdateView() ),
+			m_lv_table_nat, TQ_SLOT( slotUpdateView() ) );
+		connect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+			m_lv_table_nat, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Mangle View" << endl;
 		m_lv_table_mangle->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 	} else if  ( lv == m_lv_table_mangle ) {
 		setEnabled( true );
 
 		kdDebug() << "Disabling Filter View" << endl;
 		m_lv_table_filter->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Nat View" << endl;
 		m_lv_table_nat->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Enabling Mangle View" << endl;
 		m_lv_table_mangle->setEnabled( true );
-		connect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		connect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		connect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		connect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 	} else  if ( ! lv ){
 		kdDebug() << "Disabling Filter View" << endl;
 		m_lv_table_filter->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_filter, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_filter, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Nat View" << endl;
 		m_lv_table_nat->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 
 		kdDebug() << "Disabling Mangle View" << endl;
 		m_lv_table_mangle->setEnabled( false );
-		disconnect( this, TQT_SIGNAL( sigUpdateView() ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView() ) );
-		disconnect( this, TQT_SIGNAL( sigUpdateView( NetfilterObject* ) ),
-	         m_lv_table_mangle, TQT_SLOT( slotUpdateView( NetfilterObject* ) ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView() ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView() ) );
+		disconnect( this, TQ_SIGNAL( sigUpdateView( NetfilterObject* ) ),
+	         m_lv_table_mangle, TQ_SLOT( slotUpdateView( NetfilterObject* ) ) );
 	}
 }
 
@@ -967,7 +967,7 @@ void KMFRuleEdit::slotEditNetwork() {
 // 	KMFMyNetworkWidget *wid = new KMFMyNetworkWidget( this, "name" );
 // 	wid->setNetwork( m_network );
 // 	wid->slotUpdateView();
-/*	connect( wid, TQT_SIGNAL( sigActiveTargetChanged() ), this, TQT_SLOT( slotUpdateView() ) );*/
+/*	connect( wid, TQ_SIGNAL( sigActiveTargetChanged() ), this, TQ_SLOT( slotUpdateView() ) );*/
 	m_myNetworkWidget->slotUpdateView();
 	m_app->setOutputWidget( m_myNetworkWidget );
 	m_app->showOutput();
@@ -1156,7 +1156,7 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			TQString lab_str = i18n("Table: %1").arg( name );
 
 			m_contextMenu->insertTitle( lab_str );
-			m_contextMenu->insertItem( icon_new, i18n( "Add Chain..." ), this, TQT_SLOT( slotAddChain() ) );
+			m_contextMenu->insertItem( icon_new, i18n( "Add Chain..." ), this, TQ_SLOT( slotAddChain() ) );
 		}
 		break;
 		case NetfilterObject::CHAIN:
@@ -1166,14 +1166,14 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			TQString lab_str = i18n("Chain: %1").arg( name );
 
 			m_contextMenu->insertTitle( icon_chain, lab_str );
-			m_contextMenu->insertItem( icon_new, i18n( "Add Rule..." ), this, TQT_SLOT( slotAddRule() ) );
+			m_contextMenu->insertItem( icon_new, i18n( "Add Rule..." ), this, TQ_SLOT( slotAddRule() ) );
 			m_contextMenu->insertSeparator();
 			if ( ! chain->isBuildIn() )
-				m_contextMenu->insertItem( icon_edit, i18n( "Chain Documentation" ), this, TQT_SLOT( slotEditChainInfo() ) );
-			m_contextMenu->insertItem( icon_new, i18n( "Add Chain..." ), this, TQT_SLOT( slotAddChain() ) );
-			m_contextMenu->insertItem( icon_edit, i18n( "Edit Chain" ), this, TQT_SLOT( slotEditChain() ) );
+				m_contextMenu->insertItem( icon_edit, i18n( "Chain Documentation" ), this, TQ_SLOT( slotEditChainInfo() ) );
+			m_contextMenu->insertItem( icon_new, i18n( "Add Chain..." ), this, TQ_SLOT( slotAddChain() ) );
+			m_contextMenu->insertItem( icon_edit, i18n( "Edit Chain" ), this, TQ_SLOT( slotEditChain() ) );
 			if ( ! chain->isBuildIn() )
-				m_contextMenu->insertItem( icon_del, i18n( "Delete Chain" ), this, TQT_SLOT( slotDelChain() ) );
+				m_contextMenu->insertItem( icon_del, i18n( "Delete Chain" ), this, TQ_SLOT( slotDelChain() ) );
 		}
 		case NetfilterObject::RULE:
 		if ( IPTRule* rule =  dynamic_cast<IPTRule*> ( obj ) ) {
@@ -1187,26 +1187,26 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			for( uint i = 0; i < m_editPlugins.count(); i++ ) {
 				sub_edit->insertItem( icon_edit, i18n( "Edit %1" ).arg(m_editPlugins.at(i)->optionEditName() ), i );
 			}
-			connect( sub_edit,TQT_SIGNAL(activated( int ) ), 
-				this,TQT_SLOT(slotNewOptionType( int ) ) );			
+			connect( sub_edit,TQ_SIGNAL(activated( int ) ), 
+				this,TQ_SLOT(slotNewOptionType( int ) ) );			
 			m_contextMenu->insertItem( i18n( "Edit Rule Option" ), sub_edit );
-			// m_contextMenu->insertItem( icon_new, i18n( "Add Rule..." ), this, TQT_SLOT( slotAddRule() ) );
-			m_contextMenu->insertItem( icon_new, i18n( "Insert Rule..." ), this, TQT_SLOT( slotAddRule() ) );
+			// m_contextMenu->insertItem( icon_new, i18n( "Add Rule..." ), this, TQ_SLOT( slotAddRule() ) );
+			m_contextMenu->insertItem( icon_new, i18n( "Insert Rule..." ), this, TQ_SLOT( slotAddRule() ) );
 //			m_contextMenu->insertSeparator();
-			m_contextMenu->insertItem( icon_del, i18n( "Delete Rule" ), this, TQT_SLOT( slotDelRule() ) );
+			m_contextMenu->insertItem( icon_del, i18n( "Delete Rule" ), this, TQ_SLOT( slotDelRule() ) );
 			m_contextMenu->insertSeparator();
-			m_contextMenu->insertItem( icon_rename, i18n( "Rename Rule" ), this, TQT_SLOT( slotRenameRule() ) );
-			m_contextMenu->insertItem( icon_edit, i18n( "Rule Documentation" ), this, TQT_SLOT( slotEditRuleInfo() ) );
-			m_contextMenu->insertItem( icon_up, i18n( "Move Up" ), this, TQT_SLOT( slotMoveRuleUp() ) );
-			m_contextMenu->insertItem( icon_down, i18n( "Move Down" ), this, TQT_SLOT( slotMoveRuleDown() ) );
+			m_contextMenu->insertItem( icon_rename, i18n( "Rename Rule" ), this, TQ_SLOT( slotRenameRule() ) );
+			m_contextMenu->insertItem( icon_edit, i18n( "Rule Documentation" ), this, TQ_SLOT( slotEditRuleInfo() ) );
+			m_contextMenu->insertItem( icon_up, i18n( "Move Up" ), this, TQ_SLOT( slotMoveRuleUp() ) );
+			m_contextMenu->insertItem( icon_down, i18n( "Move Down" ), this, TQ_SLOT( slotMoveRuleDown() ) );
 			m_contextMenu->insertSeparator();
-			m_contextMenu->insertItem( icon_edit, i18n( "Edit Chain" ), this, TQT_SLOT( slotEditChain() ) );
+			m_contextMenu->insertItem( icon_edit, i18n( "Edit Chain" ), this, TQ_SLOT( slotEditChain() ) );
 			if ( ! rule->chain()->isBuildIn() )
-				m_contextMenu->insertItem( icon_del, i18n( "Delete Chain" ), this, TQT_SLOT( slotDelChain() ) );
+				m_contextMenu->insertItem( icon_del, i18n( "Delete Chain" ), this, TQ_SLOT( slotDelChain() ) );
 			m_contextMenu->insertSeparator();
 
 			TDEPopupMenu *sub_copy = new TDEPopupMenu( m_contextMenu );
-			connect( sub_copy, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotCopyRule( int ) ) );
+			connect( sub_copy, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotCopyRule( int ) ) );
 			sub_copy->insertTitle( i18n( "Copy to Chain" ) );
 			TQPtrList<IPTChain> chains = m_table ->chains();
 			for ( uint i = 0; i < chains.count(); i++ ) {
@@ -1216,7 +1216,7 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			m_contextMenu->insertItem( icon_copy, i18n( "Copy Rule" ), sub_copy );
 
 			TDEPopupMenu *sub_move = new TDEPopupMenu( m_contextMenu );
-			connect( sub_move, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotMoveRule( int ) ) );
+			connect( sub_move, TQ_SIGNAL( activated( int ) ), this, TQ_SLOT( slotMoveRule( int ) ) );
 			sub_move->insertTitle( i18n( "Move to Chain" ) );
 			TQPtrList<IPTChain> chains2 = m_table->chains();
 			for ( uint i = 0; i < chains2.count(); i++ ) {
