@@ -30,7 +30,7 @@ namespace KMF {
   */
 
 class KDE_EXPORT KMFCheckListOutput : public TQDialog {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFCheckListOutput( TQWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0 );
