@@ -32,7 +32,7 @@
 
 namespace KMF {
 class KDE_EXPORT KMFMainWindow : public KParts::MainWindow, virtual public KMyFirewallInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 
