@@ -28,7 +28,7 @@
 class TQKeyEvent;
 namespace KMF {
 class KDE_EXPORT KMFNewDocDlg : public KMyFirewallNewDocument  {
-   Q_OBJECT
+   TQ_OBJECT
   
 public: 
 	KMFNewDocDlg(TQWidget *parent=0, const char *name=0, WFlags fl = 0);
