@@ -29,7 +29,7 @@ class NetfilterObject;
 class KMFDoc;
 
 class KDE_EXPORT KMFObjectInfo : public KMyFirewallObjectInfo  {
-   Q_OBJECT
+   TQ_OBJECT
   
 public: 
 	KMFObjectInfo(TQWidget *parent=0, const char *name=0, bool modal=false);
