@@ -28,7 +28,7 @@ namespace KMF {
 class KMFError;
 
 class KDE_EXPORT KMFPortWidget : public KMyFirewallPortWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFPortWidget( TQWidget *parent = 0, const char *name = 0 );
