@@ -32,7 +32,7 @@ class KMFNetZone;
 class KMFNetHost;
 
 class KMFProtocolListView : public KMyFirewallProtocolListView {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
