@@ -28,7 +28,7 @@ class KMFProtocolUsage;
 class KMFProtocolCategory;
 
 class KMFProtocolPropertiesWidget : public KMyFirewallProtocolPropertiesWidget {
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public:
