@@ -15,7 +15,7 @@
 
 #include "kmyfirewallselectactivetarget.h"
 
-// QT Includes
+// TQt Includes
 #include <tqstring.h>
 #include <tqguardedptr.h>
 #include <tqpoint.h>
@@ -27,7 +27,7 @@ class KMFTarget;
 
 class KMFSelectActiveTarget : public KMyFirewallSelectActiveTarget
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 	public: static KMFTarget* selectTarget( KMFNetwork* network, const TQString& msg );
 	
