@@ -15,7 +15,7 @@
 
 #include "kmyfirewallselectinterface.h"
 
-// QT Includes
+// TQt Includes
 #include <tqstringlist.h>
 
 // KDE Includes
@@ -26,7 +26,7 @@
 
 namespace KMF {
 class KDE_EXPORT KMFSelectInterface : public KMyFirewallSelectInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
