@@ -12,7 +12,7 @@
 #include "kmfruleoptioneditinterface.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -33,12 +33,12 @@ KMFRuleOptionEditorInterface::KMFRuleOptionEditorInterface(TQObject *parent, con
 	m_edit = new KMFRuleEditorInterface( 0 , "Edit", 0 );
 	m_edit->hide();
 
-/*	connect( m_edit,TQT_SIGNAL(sigAddRuleOpt(TQString*, TQPtrList< TQString >* ) ), 
-		this,TQT_SLOT( slotAddRuleOption(TQString*, TQPtrList< TQString >* ) ) );
-	connect( m_edit,TQT_SIGNAL(sigAddTargetOpt(TQString*, TQPtrList< TQString >* ) ), 
-		this,TQT_SLOT( slotAddTargetOption(TQString*, TQPtrList< TQString >* ) ) );*/
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+/*	connect( m_edit,TQ_SIGNAL(sigAddRuleOpt(TQString*, TQPtrList< TQString >* ) ), 
+		this,TQ_SLOT( slotAddRuleOption(TQString*, TQPtrList< TQString >* ) ) );
+	connect( m_edit,TQ_SIGNAL(sigAddTargetOpt(TQString*, TQPtrList< TQString >* ) ), 
+		this,TQ_SLOT( slotAddTargetOption(TQString*, TQPtrList< TQString >* ) ) );*/
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 KMFRuleOptionEditorInterface::~KMFRuleOptionEditorInterface() {}
 
