@@ -24,7 +24,7 @@
 #include "kmfruleoptioneditlimit.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -45,8 +45,8 @@ KMFRuleOptionEditLimit::KMFRuleOptionEditLimit(TQObject *parent, const char *nam
 	m_edit = new KMFRuleEditorLimit( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 KMFRuleOptionEditLimit::~KMFRuleOptionEditLimit() {}
 
