@@ -13,7 +13,7 @@
 #include "kmfruleoptioneditmac.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -34,8 +34,8 @@ KMFRuleOptionEditMAC::KMFRuleOptionEditMAC(TQObject *parent, const char *name)
 	m_edit = new KMFRuleEditMac( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 
 KMFRuleOptionEditMAC::~KMFRuleOptionEditMAC() {}
