@@ -24,7 +24,7 @@
 #include "kmfruletargetoptioneditnat.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -49,8 +49,8 @@ KMFRuleTargetOptionEditNat::KMFRuleTargetOptionEditNat(TQObject *parent, const c
 	m_edit = new KMFRuleEditorTargetNat( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 
 KMFRuleTargetOptionEditNat::~KMFRuleTargetOptionEditNat() {}
