@@ -24,7 +24,7 @@
 #include "kmfruleoptioneditstate.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -45,8 +45,8 @@ KMFRuleOptionEditState::KMFRuleOptionEditState(TQObject *parent, const char *nam
 	m_edit = new KMFRuleEditorState( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 
 KMFRuleOptionEditState::~KMFRuleOptionEditState() {}
