@@ -24,7 +24,7 @@
 #include "kmfruleoptionedittos.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -45,8 +45,8 @@ KMFRuleOptionEditTos::KMFRuleOptionEditTos(TQObject *parent, const char *name)
 	m_edit = new KMFRuleEditorTos( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 
 KMFRuleOptionEditTos::~KMFRuleOptionEditTos() {}
