@@ -12,7 +12,7 @@
 #include "kmfruletargetoptionedittos.h"
 
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 
 // KDE includes
@@ -37,8 +37,8 @@ KMFRuleTargetOptionEditTos::KMFRuleTargetOptionEditTos(TQObject *parent, const c
 	m_edit = new KMFRuleEditorTos( 0 , "Edit", 0 );
 	m_edit->hide();
 
-	connect( m_edit,TQT_SIGNAL(sigHideMe() ), 
-		this,TQT_SLOT( slotShowOverview() ) );
+	connect( m_edit,TQ_SIGNAL(sigHideMe() ), 
+		this,TQ_SLOT( slotShowOverview() ) );
 }
 
 KMFRuleTargetOptionEditTos::~KMFRuleTargetOptionEditTos() {}
